@@ -25,7 +25,9 @@ Foundation; version 2 of the licence.
 #include "support.h"
 #include "main.h"
 #include "prefs.h"
+#include "selected_disc.h"
 #include "threads.h"
+#include "upload.h"
 #include "util.h"
 
 gboolean
@@ -134,7 +136,7 @@ on_year_focus_out_event        (GtkWidget       *widget,
     if((text[0] != '1' && text[0] != '2') || text[1] < '0' || text[1] > '9' ||
         text[2] < '0' || text[2] > '9' || text[3] < '0' || text[3] > '9')
     {
-        sprintf(text, "1900");
+        sprintf(text, "%d", EMPTY_YEAR_SHOWN);
     }
     
     gtk_entry_set_text(GTK_ENTRY(widget), text);
@@ -185,7 +187,7 @@ on_album_genre_focus_out_event         (GtkWidget       *widget,
     trim_whitespace(text);
     
     if(text[0] == '\0')
-        gtk_entry_set_text(GTK_ENTRY(widget), "Unknown");
+        gtk_entry_set_text(GTK_ENTRY(widget), EMPTY_GENRE_SHOWN);
     else
         gtk_entry_set_text(GTK_ENTRY(widget), text);
     
@@ -353,13 +355,39 @@ void
 on_pick_disc_changed                   (GtkComboBox     *combobox,
                                         gpointer         user_data)
 {
-    gint selected = gtk_combo_box_get_active(combobox);
+    gint selected_idx = gtk_combo_box_get_active(combobox);
     if (gbl_disc_matches == NULL ||
-        selected == -1 ||
-        (guint)selected >= g_list_length(gbl_disc_matches))
+        selected_idx == -1 ||
+        (guint)selected_idx >= g_list_length(gbl_disc_matches))
+    {
         return;
-    cddb_disc_t * disc = g_list_nth_data(gbl_disc_matches, selected);
-    update_tracklist(disc);
+    }
+
+    glb_selected_disc_free();
+
+	cddb_disc_t * selected_disc = g_list_nth_data(gbl_disc_matches, selected_idx);
+
+	log_disc_info(selected_disc, "selected: ");
+    update_tracklist(selected_disc);
+
+    glb_selected_disc_clone_from(selected_disc);
+}
+
+
+void
+on_pick_category_changed               (GtkComboBox     *combobox,
+                                        gpointer         user_data)
+{
+	char buf[1024];
+	unsigned int max_buf = sizeof(buf) - 1;
+	
+    gint selected_idx = gtk_combo_box_get_active(combobox);
+    if (selected_idx == -1)
+    {
+        return;
+    }
+    snprintf(buf, max_buf, "selected category %d = %s\n", selected_idx, CDDB_CATEGORY[selected_idx]);
+    debugLog(buf);
 }
 
 void
@@ -382,9 +410,17 @@ on_prefs_response                      (GtkDialog       *dialog,
         if (!prefs_are_valid())
             return;
         
-        get_prefs_from_widgets(global_prefs);
+        // ensure that global_prefs always points to a valid struct
+        // - a thread safe solution needs a gmutex to protect each access of global_prefs,
+        //   but this is a lot of work to implement, so for now this may suffice ...
+        prefs * old_prefs = global_prefs;
+        global_prefs = get_prefs_from_widgets(); // points to new struct
+
         save_prefs(global_prefs);
         toggle_allow_tracknum();
+        upload_toggle_enable();
+
+        delete_prefs(old_prefs); // can safely removed now
     }
     
     gtk_widget_destroy(GTK_WIDGET(dialog));    
@@ -584,21 +620,21 @@ toggle_joined_title_artist                      (void)
     {
         concatenate_artist_track();
         gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(lookup_widget(win_main,
-                        "single_artist")), TRUE);
+                        SINGLE_ARTIST_BUTTON)), TRUE);
         join_artist_title = JOIN_ON;
     }
     else
     {
         gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(lookup_widget(win_main,
-                        "single_artist")), FALSE);
+                        SINGLE_ARTIST_BUTTON)), FALSE);
         join_artist_title = JOIN_OFF;
     }
 
     GtkTreeViewColumn * concatenatedCol = gtk_tree_view_get_column(
-            GTK_TREE_VIEW(tracklist), COL_TRACKARTISTTITLE);
+            GTK_TREE_VIEW(glb_tracklist), COL_TRACKARTISTTITLE);
     gtk_tree_view_column_set_visible(concatenatedCol, join_artist_title == JOIN_ON);
 
-    GtkTreeViewColumn * titleCol = gtk_tree_view_get_column(GTK_TREE_VIEW(tracklist),
+    GtkTreeViewColumn * titleCol = gtk_tree_view_get_column(GTK_TREE_VIEW(glb_tracklist),
             COL_TRACKTITLE );
     gtk_tree_view_column_set_visible(titleCol, join_artist_title == JOIN_OFF);
 }
@@ -941,7 +977,7 @@ void
 on_single_artist_toggled               (GtkToggleButton *togglebutton,
                                         gpointer         user_data)
 {
-    GtkTreeViewColumn * artistCol = gtk_tree_view_get_column(GTK_TREE_VIEW(tracklist),
+    GtkTreeViewColumn * artistCol = gtk_tree_view_get_column(GTK_TREE_VIEW(glb_tracklist),
             COL_TRACKARTIST ); //lnr
     gtk_tree_view_column_set_visible(artistCol,
             !gtk_toggle_button_get_active(togglebutton));
