@@ -1,4 +1,6 @@
 #include <stdbool.h>
+#include <cddb/cddb.h>
+
 
 void debugLog(const char* msg);
 
@@ -64,6 +66,11 @@ void trim_whitespace(char * str);
 // bad - the sting containing all the characters to remove
 void trim_chars(char * str, const char * bad);
 
+char* heap_copy_of(const char* source);
+
+
+extern void log_disc_info(cddb_disc_t * disc, const char* head);
+
 // LNR - It's possible that some files may end up on a MS file system,
 // so it's best to disallow MS invalid chars as well. I also disallow
 // period (dot) because it screws up my file name database software. YMMV
